Learn R Programming

epandist (version 1.0.1)

cepan: Calculate censoring point

Description

This function calculates the censoring point of a random left-censored epanechnikov-distributed variable associated a given expected value. The inverse of this function is evepan.

Usage

cepan(ev, mu = 0, r = 5^0.5)

Arguments

ev
expected value.
mu
mean of distribution prior to censoring.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.

Value

  • the censoring point associated with ev, mu and r.

Examples

Run this code
cepan(ev=103,mu=100,r=16) #Expected value of an epan-distributed variable left-censored at 103

Run the code above in your browser using DataLab