Learn R Programming

epandist (version 1.0.1)

depan: Probability density function (pdf) for an uncensored epanechnikov distribution

Description

This function is simply a polynomial of second degree.

Usage

depan(x = 0, mu = 0, r = 5^0.5)

Arguments

x
point on x-axis.
mu
mean of distribution.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.

Value

  • point density associated with x, mu and r.

Examples

Run this code
curve(dnorm(x),xlim=c(-3,3))
curve(depan(x),add=TRUE,col="green")

Run the code above in your browser using DataLab