Learn R Programming

epandist (version 1.0.1)

evepan: Calculate expected value of censored variable

Description

This function calculates the expected value of a random left-censored epanechnikov-distributed variable with a given censoring point. The inverse of this function is cepan.

Usage

evepan(c = 0, mu = 0, r = 5^0.5)

Arguments

c
censoring point.
mu
mean of distribution prior to censoring.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.

Value

  • the expected value associated with c, mu and r.

Examples

Run this code
evepan(c=100,mu=100,r=10) #Expected value of an epan-distributed variable left-censored at 100

Run the code above in your browser using DataLab