Learn R Programming

epandist (version 1.0.1)

pepan: Cumulative distribution function (cdf) for an uncensored epanechnikov distribution

Description

The inverse of this function is qepan.

Usage

pepan(x = 0, mu = 0, r = 5^0.5)

Arguments

x
point on x-axis.
mu
mean of distribution.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.

Value

  • probability of value below x given mu and r.

Examples

Run this code
pepan(x=-1.96,mu=0,r=5^.5) #Probability of a value below -1.96

Run the code above in your browser using DataLab