Learn R Programming

epandist (version 1.0.1)

repan: Generate random uncensored epanechnikov-distributed data

Description

This function works in conjuncture with qepan and runif

Usage

repan(n, mu = 0, r = 5^0.5)

Arguments

n
number of data points.
mu
mean of distribution.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.

Value

  • vector of random variables.

Examples

Run this code
hist(repan(10000,mu=100,r=10)) #Generates and plots 10000 random observations

Run the code above in your browser using DataLab