This function calculates the censoring point of a random left-censored epanechnikov-distributed variable associated a given expected value.
The inverse of this function is evepan.
Usage
cepan(ev, mu = 0, r = 5^0.5)
Arguments
ev
expected value.
mu
mean of distribution prior to censoring.
r
half the range of the distribution, ie the distance from the mean to the smallest/largest value supported by the distribution. r=5^.5 corresponds to a standard deviation of 1.